@@ -108,7 +108,7 @@ def get_instance_info(instances, class_instance):
         matching_hint = False
         instance_id = instance['Instances'][0]['InstanceId']
         image_id = instance['Instances'][0]['ImageId']
-        instance_key_name = instance['Instances'][0]['KeyName']
+        instance_key_name = instance['Instances'][0]['KeyName'] or "none"
         class_instance.start_instance_id = instance_id
         class_instance.start_image_id = image_id
         state_code = instance['Instances'][0]['State']['Code']
